"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const sendEmailResponseResponse = {
    MessageId: 'message-id',
};
const sendRawEmailResponseResponse = {
    MessageId: 'message-id',
};
const sendEmail = jest.fn().mockImplementation(() => {
    return Promise.resolve(sendEmailResponseResponse);
});
const sendRawEmail = jest.fn().mockImplementation(() => {
    return Promise.resolve(sendRawEmailResponseResponse);
});
jest.mock('@aws-sdk/client-ses', () => {
    return {
        SES: jest.fn().mockImplementation(() => {
            return {
                sendEmail,
                sendRawEmail,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const sesHelperMock = new helper_1.SESHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.SESHelper.name}.${sesHelperMock.SendEmailAsync.name}`, () => {
    const action = `${helper_1.SESHelper.name}.${sesHelperMock.SendEmailAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} subject`, () => {
        const actual = sesHelperMock.SendEmailAsync(TestValues.EmptyString, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} subject`);
    });
    test(`${TestValues.ThrowsOnEmpty} toAddresses`, () => {
        const actual = sesHelperMock.SendEmailAsync(TestValues.Subject, TestValues.EmptyArray, TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} toAddresses`);
    });
    test(`${TestValues.ThrowsOnEmpty} fromAddress`, () => {
        const actual = sesHelperMock.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} fromAddress`);
    });
    test(TestValues.ValidTest, () => {
        const actual = sesHelperMock.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).resolves.toEqual(sendEmailResponseResponse);
    });
});
describe(`${helper_1.SESHelper.name}.${sesHelperMock.SendEmailWithAttachmentsAsync.name}`, () => {
    const action = `${helper_1.SESHelper.name}.${sesHelperMock.SendEmailWithAttachmentsAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} fromAddress`, () => {
        const emailObject = {
            FromAddress: TestValues.EmptyString,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} fromAddress`);
    });
    test(`${TestValues.ThrowsOnEmpty} messageBody`, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.EmptyString,
            Subject: TestValues.Subject,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} messageBody`);
    });
    test(`${TestValues.ThrowsOnEmpty} subject`, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.EmptyString,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} subject`);
    });
    test(`${TestValues.ThrowsOnEmpty} toAddresses`, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            ToAddresses: [],
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} at least one toAddress`);
    });
    test(`${TestValues.ThrowsOnEmpty} attachmentContents`, () => {
        const attachments = [
            {
                Contents: TestValues.EmptyString,
                ContentType: TestValues.ContentType,
                Name: TestValues.Name,
            },
        ];
        const emailObject = {
            ToAddresses: [TestValues.EmailAddress],
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            Attachments: attachments,
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attachment contents`);
    });
    test(`${TestValues.ThrowsOnEmpty} attachmentContentType`, () => {
        const attachments = [
            {
                Contents: TestValues.Body,
                ContentType: TestValues.EmptyString,
                Name: TestValues.Name,
            },
        ];
        const emailObject = {
            ToAddresses: [TestValues.EmailAddress],
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            Attachments: attachments,
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attachment contentType`);
    });
    test(`${TestValues.ThrowsOnEmpty} attachmentName`, () => {
        const attachments = [
            {
                Contents: TestValues.ContentType,
                ContentType: TestValues.ContentType,
                Name: TestValues.EmptyString,
            },
        ];
        const emailObject = {
            ToAddresses: [TestValues.EmailAddress],
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            Attachments: attachments,
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attachment name`);
    });
    test(TestValues.ValidTest, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).resolves.toEqual(TestValues.SendRawEmailResponse);
    });
    test(`${TestValues.ValidTest} with attachments`, () => {
        const attachments = [
            {
                Contents: TestValues.Body,
                ContentType: TestValues.ContentType,
                Name: TestValues.Name,
            },
        ];
        const emailObject = {
            ToAddresses: [TestValues.EmailAddress],
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            Attachments: attachments,
        };
        const actual = sesHelperMock.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).resolves.toEqual(TestValues.SendRawEmailResponse);
    });
});
//# sourceMappingURL=helper-resolves.spec.js.map