"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SESHelper = void 0;
const SES = require("@aws-sdk/client-ses");
const typescript_helper_functions_1 = require("typescript-helper-functions");
class SESHelper extends typescript_helper_functions_1.BaseClass {
    constructor(logger, repository, options) {
        super(logger);
        options = this.ObjectOperations.IsNullOrEmpty(options)
            ? { region: 'us-east-1' }
            : options;
        this.Repository = repository || new SES.SES(options);
    }
    async SendEmailAsync(subject, toAddresses, fromAddress, body) {
        const action = `${SESHelper.name}.${this.SendEmailAsync.name}`;
        this.LogHelper.LogInputs(action, {
            subject,
            toAddresses,
            fromAddress,
            body,
        });
        if (this.ObjectOperations.IsNullOrWhitespace(subject)) {
            throw new Error(`[${action}]-Must supply subject`);
        }
        if (this.ObjectOperations.IsNullOrEmpty(toAddresses)) {
            throw new Error(`[${action}]-Must supply toAddresses`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(fromAddress)) {
            throw new Error(`[${action}]-Must supply fromAddress`);
        }
        const params = {
            Destination: {
                ToAddresses: toAddresses,
            },
            Message: {
                Body: {
                    Html: {
                        Data: body.toString(),
                    },
                },
                Subject: {
                    Data: subject,
                },
            },
            Source: fromAddress,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.sendEmail(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async SendEmailWithAttachmentsAsync(emailObject) {
        const action = `${SESHelper.name}.${this.SendEmailWithAttachmentsAsync.name}`;
        this.LogHelper.LogInputs(action, emailObject);
        const attachments = emailObject.Attachments || [];
        if (this.ObjectOperations.IsNullOrWhitespace(emailObject.FromAddress)) {
            throw new Error(`[${action}]-Must supply fromAddress`);
        }
        if (this.ObjectOperations.IsNullOrEmpty(emailObject.MessageBody)) {
            throw new Error(`[${action}]-Must supply messageBody`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(emailObject.Subject)) {
            throw new Error(`[${action}]-Must supply subject`);
        }
        if (emailObject.ToAddresses.length === 0) {
            throw new Error(`[${action}]-Must supply at least one toAddress`);
        }
        for (const attachment of attachments) {
            if (this.ObjectOperations.IsNullOrWhitespace(attachment.Name)) {
                throw new Error(`[${action}]-Must supply attachment name`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(attachment.ContentType)) {
                throw new Error(`[${action}]-Must supply attachment contentType`);
            }
            if (this.ObjectOperations.IsNullOrEmpty(attachment.Contents)) {
                throw new Error(`[${action}]-Must supply attachment contents`);
            }
        }
        let rawMessageData = '';
        rawMessageData += `Subject:${emailObject.Subject}\n`;
        rawMessageData += 'MIME-Version: 1.0\n';
        rawMessageData += 'Content-type: Multipart/Mixed; ';
        rawMessageData += 'boundary="NextPart"\n\n--NextPart\n';
        rawMessageData += 'Content-Type: text/plain\n\n';
        rawMessageData += `${emailObject.MessageBody}\n\n--NextPart`;
        if (attachments.length > 0) {
            rawMessageData += `\nContent-Type: multipart/alternative;\n\t`;
            rawMessageData += 'boundary="sub_NextPart"\n\n--sub_NextPart';
            for (const attachment of attachments) {
                rawMessageData += `\nContent-Type: ${attachment.ContentType}; `;
                rawMessageData += `name="${attachment.Name}"\n`;
                rawMessageData += `Content-Description: ${attachment.Name}\n`;
                rawMessageData += `Content-Disposition: attachment;`;
                rawMessageData += `filename="${attachment.Name}";\n\n`;
                rawMessageData += `${attachment.Contents}\n`;
                rawMessageData += `\n--sub_NextPart`;
            }
            rawMessageData += `--\n\n--NextPart`;
        }
        rawMessageData += `--`;
        const rawMessageDataBuffer = this.ObjectOperations.ConvertStringToArrayBuffer(rawMessageData);
        const rawMessage = { Data: rawMessageDataBuffer };
        const request = {
            Destinations: emailObject.ToAddresses,
            Source: emailObject.FromAddress,
            RawMessage: rawMessage,
        };
        this.LogHelper.LogRequest(action, request);
        const response = await this.Repository.sendRawEmail(request);
        this.LogHelper.LogRequest(action, response);
        return response;
    }
}
exports.SESHelper = SESHelper;
//# sourceMappingURL=helper.js.map